@@ -43,6 +43,9 @@ public:
     bool suspended() const;
     void setSuspended(bool suspended);
 
+    bool forceDashActive() const override;
+    void setForceDashActive(bool forceDashActive) override;
+
     Q_INVOKABLE unity::shell::application::ApplicationInfoInterface *get(const int index) const;
 
     Q_INVOKABLE unity::shell::application::ApplicationInfoInterface *findApplication(const QString &appId) const;
@@ -57,8 +60,6 @@ public:
 
     Q_INVOKABLE bool stopApplication(const QString &appId);
 
-    Q_INVOKABLE bool updateScreenshot(const QString &appId);
-
 private:
     QList<MockApplicationInfo*> m_list;
 };
